"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.createToken = exports.uploadFormData = exports.upload = void 0;

var _s = _interopRequireDefault(require("aws-sdk/clients/s3"));

var _fs = _interopRequireDefault(require("fs"));

var _request = _interopRequireDefault(require("request"));

var _v = _interopRequireDefault(require("uuid/v4"));

var _crypto = _interopRequireDefault(require("crypto"));

var _createCloudFrontDistribution = _interopRequireDefault(require("./resource/createCloudFrontDistribution"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const createPresignedPut = async ({
  s3,
  bucket,
  config: {
    deploymentId
  }
}, dir) => {
  const uploadId = (0, _v.default)();
  const uploadUrl = await s3.getSignedUrlPromise('putObject', {
    Bucket: bucket,
    Key: `${deploymentId}/${dir}/${uploadId}`
  });
  return {
    uploadUrl,
    uploadId
  };
};

const upload = (pool, uploadUrl, filePath) => {
  const fileSizeInBytes = _fs.default.statSync(filePath).size;

  const fileStream = _fs.default.createReadStream(filePath);

  return new Promise((resolve, reject) => _request.default.put({
    headers: {
      'Content-Length': fileSizeInBytes
    },
    uri: uploadUrl,
    body: fileStream
  }, (error, _, body) => {
    error ? reject(error) : body ? reject(body) : resolve();
  }));
};

exports.upload = upload;

const createPresignedPost = async ({
  s3,
  bucket,
  config: {
    deploymentId
  }
}, dir) => {
  const uploadId = (0, _v.default)();
  const form = await new Promise((resolve, reject) => {
    s3.createPresignedPost({
      Bucket: bucket,
      Fields: {
        Key: `${deploymentId}/${dir}/${uploadId}`
      }
    }, (error, data) => {
      error ? reject(error) : resolve(data);
    });
  });
  return {
    form,
    uploadId
  };
};

const uploadFormData = (pool, form, filePath) => {
  const fileStream = _fs.default.createReadStream(filePath);

  form.fields.key = form.fields.Key;
  delete form.fields.Key;
  return new Promise((resolve, reject) => _request.default.post({
    url: form.url,
    formData: _objectSpread({}, form.fields, {
      file: fileStream
    })
  }, error => {
    error ? reject(error) : resolve();
  }));
};

exports.uploadFormData = uploadFormData;

const createToken = ({
  config: {
    deploymentId,
    secretKey
  }
}, {
  dir,
  expireTime
}) => {
  const payload = Buffer.from(JSON.stringify({
    deploymentId,
    dir,
    expireTime: Date.now() + expireTime
  })).toString('base64').replace(/=/g, '');

  const signature = _crypto.default.createHmac('md5', secretKey).update(payload).digest('hex');

  return `${payload}*${signature}`;
};

exports.createToken = createToken;

const createUploadAdapter = config => {
  const {
    accessKeyId,
    secretAccessKey,
    region,
    bucket,
    endpoint,
    deploymentId,
    CDN,
    secretKey
  } = config;
  const s3 = new _s.default({
    credentials: {
      accessKeyId,
      secretAccessKey
    },
    endpoint,
    region,
    signatureVersion: 'v4',
    useAccelerateEndpoint: true
  });
  const pool = {
    config,
    s3,
    bucket
  };
  return Object.freeze({
    createPresignedPut: createPresignedPut.bind(null, pool),
    upload: upload.bind(null, pool),
    createPresignedPost: createPresignedPost.bind(null, pool),
    uploadFormData: uploadFormData.bind(null, pool),
    deploymentId,
    CDN,
    secretKey,
    createToken,
    resource: {
      create: _createCloudFrontDistribution.default.bind(null, {
        accessKeyId,
        secretAccessKey,
        bucketName: bucket,
        region
      })
    }
  });
};

var _default = createUploadAdapter;
exports.default = _default;
//# sourceMappingURL=index.js.map